@@ -14,6 +14,7 @@ foreach my $file (@ARGV) {
 
     # I don't use functionUtilkde::substInFile because it touches all files, even those which were not modified.
     my $modified;
+    my %varname = ();
     open(my $FILE, "<", $file) or warn "We can't open file $file:$!\n";
     my @l = map {
         my $orig = $_;
@@ -23,6 +24,32 @@ foreach my $file (@ARGV) {
         s/class KUrl\;/class QUrl\;/;
         s/KUrl\(\)\;/QUrl()\;/;
         s/KUrl::toPercentEncoding\b/QUrl::toPercentEncoding/;
+        s/KUrl::fromPercentEncoding\b/QUrl::fromPercentEncoding/;
+        s,KUrl::fromPath\b,QUrl::fromLocalFile,;
+
+        if (/\s*KUrl::List\s+(\w+);/) {
+           my $var = $1;
+           $varname{$1} = 1;
+        }
+
+        if (/(\s*)(\w+)\.populateMimeData\s*\(\s*(\w+)\s*\);/) {
+           my $var = $2;
+           if (defined $varname{$var}) {
+              my $urls = $3;
+              my $indent = $1;
+              $_ = $indent . "$urls->setUrls($var);\n";
+           }
+        }
+        if (/KUrl::List::fromMimeData\s*\(\s*(\w+)\s*\)/) {
+           my $var = $1;
+           s/KUrl::List::fromMimeData\s*\(\s*$var\s*\)/$var\-\>urls()/;
+        }
+        if (/KUrl::List::canDecode\s*\(\s*(\w+)\s*\)/) {
+           my $var = $1;
+           s/KUrl::List::canDecode\s*\(\s*$var\s*\)/$var\-\>hasUrls()/;
+        }
+
+
         # Detect variables being declared as KUrl
         if (/const KUrl\s*&\s*(\w+)/ || /^\s*KUrl\s+(\w+)\s*[=\;]/ || /^\s*KUrl\s+(\w+)\s*\(/) {
             $urls{$1} = 1;
@@ -54,6 +81,14 @@ foreach my $file (@ARGV) {
                 s/KUrl $var/QUrl $var/;
             }
         }
+        if (/(\w+)\.pass\(\)/ && defined $urls{$1}) {
+            my $url = $1;
+            s/$url\.pass\(\)/$url\.password()/g;
+        }
+        if (/(\w+)\.setPass\b/ && defined $urls{$1}) {
+            my $url = $1;
+            s/$url\.setPass\b/$url\.setPassword/g;
+        }
 
         if (/(\w+)\.protocol\(\)/ && defined $urls{$1}) {
             my $url = $1;
@@ -67,6 +102,23 @@ foreach my $file (@ARGV) {
             my $url = $1;
             s/$url\.user\(\)/$url\.userName()/g;
         }
+        if (/(\w+)\.setUser\b/ && defined $urls{$1}) {
+            my $url = $1;
+            s/$url\.setUser\b/$url\.setUserName/g;
+        }
+        if (/(\w+)\.setRef\b/ && defined $urls{$1}) {
+            my $url = $1;
+            s/$url\.setRef\b/$url\.setFragment/g;
+        }
+        if (/(\w+)\.htmlRef\(\)/ && defined $urls{$1}) {
+            my $url = $1;
+            s/$url\.htmlRef\(\)/$url\.fragment(QUrl::FullyDecoded)/g;
+        }
+        if (/(\w+)\.hasHTMLRef\(\)/ && defined $urls{$1}) {
+            my $url = $1;
+            s/$url\.hasHTMLRef\(\)/$url\.hasFragment()/g;
+        }
+
         if (/(\w+)\.hasRef\(\)/ && defined $urls{$1}) {
             my $url = $1;
             s/$url\.hasRef\(\)/$url\.hasFragment()/g;
@@ -97,6 +149,29 @@ foreach my $file (@ARGV) {
             my $url = $1;
             s/$url\.adjustPath\(KUrl::RemoveTrailingSlash\)/$url = $url\.adjusted(QUrl::StripTrailingSlash)/g;
         }
+
+        #url.setFileName(...)
+       my $regexpRange = qr/
+           ^(\s*)                        # (1) Indentation, possibly "Classname *" (the ? means non-greedy)
+           (\w+)                         # (2) variable name
+           \.setFileName\s*\((.*)\)        # (3) argument
+           (.*)$                         # (4) afterreg
+           /x; # /x Enables extended whitespace mode
+        if (my ($indent, $url, $arg, $afterreg) = $_ =~ $regexpRange) {
+           if (defined $urls{$url}) {
+              $_ = $indent . "$url = $url.adjusted(QUrl::RemoveFilename);\n";
+              $_ .= $indent . "$url.setPath($url.path() + $arg);\n";
+           }
+        }
+
+
+        #u.queryItem(QLatin1String("x-allow-unencrypted"))
+        #=> QUrlQuery(url).queryItemValue
+        if (/(\w+)\.queryItem\b/ && defined $urls{$1}) {
+           my $url = $1;
+           s/$url\.queryItem\b/QUrlQuery($url).queryItemValue/;
+        }
+
         # url.addPath(path)
         if (my ($indent, $url, $path) = /^(\s*)(\w+)\.addPath\(\s*([^\)]*)\s*\)/) {
             if (defined $urls{$url}) {
@@ -104,6 +179,13 @@ foreach my $file (@ARGV) {
             }
         }
 
+        if ( /(\w+)\.prettyUrl\(\)/ && defined $urls{$1}) {
+           my $url = $1;
+           s/$url\.prettyUrl\b/$url\.toDisplayString/;
+        }        
+        s/KUrl::List\b/QList<QUrl>/g;
+        s,\bKUrl\b,QUrl,g;
+
         $modified ||= $orig ne $_;
         $_;
     } <$FILE>;
